@@ -18,7 +18,7 @@ BEGIN {
 
 use Exporter ();
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
-$VERSION   = '2.11_004';
+$VERSION   = '2.12_001';
 $VERSION   = eval $VERSION;
 @ISA       = qw(Exporter);
 @EXPORT    = qw(mkpath rmtree);
@@ -576,7 +576,7 @@ File::Path - Create or remove directory trees
 
 =head1 VERSION
 
-This document describes version 2.11_003 of File::Path.
+This document describes version 2.12 of File::Path.
 
 =head1 SYNOPSIS
 
@@ -716,9 +716,9 @@ return value of the function is otherwise identical to make_path().
 
 The C<remove_tree> function deletes the given directories and any
 files and subdirectories they might contain, much like the Unix
-command C<rm -r> or the Windows commands C<rmdir /s> and C<rd /s>. The
+command C<rm -rf> or the Windows commands C<rmdir /s> and C<rd /s>. The
 only exception to the function similarity is C<remove_tree> accepts
-only directories whereas C<rm -r> also accepts files.
+only directories whereas C<rm -rf> also accepts files.
 
 The function accepts a list of directories to be
 removed. Its behaviour may be tuned by an optional hashref
@@ -804,9 +804,12 @@ remove_tree().
 
 =item B<NOTE:>
 
-The following error handling mechanism is considered
-experimental and is subject to change pending feedback from
-users.
+The following error handling mechanism is consistent throughout all
+code paths EXCEPT in cases where the ROOT node is nonexistent.  In
+version 2.11 the maintainers attempted to rectify this inconsistency
+but too many downstream modules encountered problems.  In such case,
+if you require root node evaluation or error checking prior to calling
+C<make_path> or C<remove_tree>, you should take additional precautions.
 
 =back
 
@@ -825,7 +828,7 @@ encountered the diagnostic key will be empty.
 An example usage looks like:
 
   remove_tree( 'foo/bar', 'bar/rat', {error => \my $err} );
-  if (@$err) {
+  if ($err && @$err) {
       for my $diag (@$err) {
           my ($file, $message) = %$diag;
           if ($file eq '') {
@@ -1090,8 +1093,9 @@ F<File::Path> B<rmtree> and B<remove_tree> will not work with multithreaded
 applications due to its use of B<chdir>.  At this time, no warning or error
 results and you will certainly encounter unexpected results.
 
-The implementation that surfaces this limitation may change in a future
-release.
+The implementation that surfaces this limitation will not be changed. See the
+F<File::Path::Tiny> module for functionality similar to F<File::Path> but does
+not B<chdir>.
 
 =head2 NFS Mount Points
 
@@ -1154,6 +1158,8 @@ Contributors to File::Path, in alphabetical order.
 
 =item Tom Lutz <F<tommylutz@gmail.com>>
 
+=item Will Sheppard <F<willsheppard@github>>
+
 =back
 
 =head1 COPYRIGHT
